@@ -1,5 +1,6 @@
 /* Miscellaneous generic support functions for GNU Make.
-Copyright (C) 1988,89,90,91,92,93,94,95,97 Free Software Foundation, Inc.
+Copyright (C) 1988, 1989, 1990, 1991, 1992, 1993, 1994, 1995, 1997,
+2002 Free Software Foundation, Inc.
 This file is part of GNU Make.
 
 GNU Make is free software; you can redistribute it and/or modify
@@ -162,7 +163,7 @@ remove_comments (line)
 {
   char *comment;
 
-  comment = find_char_unquote (line, "#", 0);
+  comment = find_char_unquote (line, '#', 0, 0);
 
   if (comment != 0)
     /* Cut off the line at the #.  */
@@ -173,7 +174,7 @@ remove_comments (line)
 
 void
 print_spaces (n)
-     register unsigned int n;
+     unsigned int n;
 {
   while (n-- > 0)
     putchar (' ');
@@ -185,10 +186,10 @@ print_spaces (n)
 
 char *
 concat (s1, s2, s3)
-     register char *s1, *s2, *s3;
+     const char *s1, *s2, *s3;
 {
-  register unsigned int len1, len2, len3;
-  register char *result;
+  unsigned int len1, len2, len3;
+  char *result;
 
   len1 = *s1 != '\0' ? strlen (s1) : 0;
   len2 = *s2 != '\0' ? strlen (s2) : 0;
@@ -336,18 +337,18 @@ strerror (errnum)
 
 void
 perror_with_name (str, name)
-     char *str, *name;
+     const char *str, *name;
 {
-  error (NILF, "%s%s: %s", str, name, strerror (errno));
+  error (NILF, _("%s%s: %s"), str, name, strerror (errno));
 }
 
 /* Print an error message from errno and exit.  */
 
 void
 pfatal_with_name (name)
-     char *name;
+     const char *name;
 {
-  fatal (NILF, "%s: %s", name, strerror (errno));
+  fatal (NILF, _("%s: %s"), name, strerror (errno));
 
   /* NOTREACHED */
 }
@@ -521,13 +522,11 @@ end_of_token_w32 (s, stopchar)
 
 char *
 next_token (s)
-     char *s;
+     const char *s;
 {
-  register char *p = s;
-
-  while (isblank ((unsigned char)*p))
-    ++p;
-  return p;
+  while (isblank ((unsigned char)*s))
+    ++s;
+  return (char *)s;
 }
 
 /* Find the next token in PTR; return the address of it, and store the
@@ -653,7 +652,7 @@ log_access (flavor)
      but we write this one to stderr because it might be
      run in a child fork whose stdout is piped.  */
 
-  fprintf (stderr, _("%s access: user %lu (real %lu), group %lu (real %lu)\n"),
+  fprintf (stderr, _("%s: user %lu (real %lu), group %lu (real %lu)\n"),
 	   flavor, (unsigned long) geteuid (), (unsigned long) getuid (),
            (unsigned long) getegid (), (unsigned long) getgid ());
   fflush (stderr);
@@ -674,7 +673,7 @@ init_access ()
   if (user_uid == -1 || user_gid == -1 || make_uid == -1 || make_gid == -1)
     pfatal_with_name ("get{e}[gu]id");
 
-  log_access (_("Initialized"));
+  log_access (_("Initialized access"));
 
   current_access = make;
 #endif
@@ -753,7 +752,7 @@ user_access ()
 
   current_access = user;
 
-  log_access ("User");
+  log_access (_("User access"));
 
 #endif	/* GETLOADAVG_PRIVILEGED */
 }
@@ -801,7 +800,7 @@ make_access ()
 
   current_access = make;
 
-  log_access ("Make");
+  log_access (_("Make access"));
 
 #endif	/* GETLOADAVG_PRIVILEGED */
 }
@@ -835,7 +834,7 @@ child_access ()
     pfatal_with_name ("child_access: setregid");
 #endif
 
-  log_access ("Child");
+  log_access (_("Child access"));
 
 #endif	/* GETLOADAVG_PRIVILEGED */
 }
@@ -858,3 +857,38 @@ get_path_max ()
   return value;
 }
 #endif
+
+
+#ifdef HAVE_BROKEN_RESTART
+
+#undef stat
+#undef readdir
+
+int
+atomic_stat(file, buf)
+     const char *file;
+     struct stat *buf;
+{
+  int r;
+
+  while ((r = stat (file, buf)) < 0)
+    if (errno != EINTR)
+      break;
+
+  return r;
+}
+
+struct dirent *
+atomic_readdir(dir)
+     DIR *dir;
+{
+  struct dirent *r;
+
+  while ((r = readdir (dir)) == NULL)
+    if (errno != EINTR)
+      break;
+
+  return r;
+}
+
+#endif  /* HAVE_BROKEN_RESTART */
